==> refined-oil-inventory-client-0.0.7-sources.jar: com/xforceplus/refinedoilinventory/controller/WarningRuleFeignApi.java <==
package com.xforceplus.refinedoilinventory.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author wangzheng
 * @date 2020-06-30
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.refinedoilinventory.entity.WarningRule;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "refined-oil-inventory")
public interface WarningRuleFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/warningRule/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param warningRule ${table.comment}
   * @return R
   */
  @PostMapping("/warningRule/add")
  public R save(@RequestBody WarningRule warningRule);

  /**
   * 修改${table.comment}
   * @param warningRule ${table.comment}
   * @return R
   */
  @PostMapping("/warningRule/update")
  public R updateById(@RequestBody WarningRule warningRule);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/warningRule/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> refined-oil-inventory-client-0.0.28-sources.jar: com/xforceplus/refinedoilinventory/controller/WarningRuleFeignApi.java <==
package com.xforceplus.refinedoilinventory.controller;


/**
 * feign客户端
 *
 * @author wangzheng
 * @date 2020-07-15
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.refinedoilinventory.entity.WarningRule;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "refined-oil-inventory")
public interface WarningRuleFeignApi {

  /**
   * 通过id查询
   * @param  id
   * @return R
   */
  @GetMapping("/warningRule/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增
   * @param warningRule 
   * @return R
   */
  @PostMapping("/warningRule/add")
  public R save(@RequestBody WarningRule warningRule);

  /**
   * 修改
   * @param warningRule 
   * @return R
   */
  @PostMapping("/warningRule/update")
  public R updateById(@RequestBody WarningRule warningRule);

  /**
   * 通过id删除
   * @param  id
   * @return R
   */
  @DeleteMapping("/warningRule/del/{id}" )
  public R removeById(@PathVariable Long id);

}
